@@ -241,14 +241,6 @@ class Object(models.Model):
                     text=text,
                     relevancy=1.0, # No weighted search yes
                     )
-    ##
-    ##
-    ##
-    def pull_now_link(self):
-        return "<A HREF='/cm/%s/%d/now/'>Get Now</A>"%(self.repo_name,self.id)
-    pull_now_link.short_description="Get Now"
-    pull_now_link.allow_tags=True
-
 ##
 ## Config
 ##
@@ -353,7 +345,6 @@ class PrefixList(Object):
         from noc.peer.resolver import resolve_as_set_prefixes
         from noc.peer.tree import optimize_prefix_list
         from noc.peer.models import PeeringPoint
-        result=[]
         for pp in PeeringPoint.objects.all():
             profile=pp.profile
             for name,filter_exp in pp.generated_prefix_lists:
@@ -363,15 +354,16 @@ class PrefixList(Object):
                     prefixes=optimize_prefix_list(prefixes)
                 prefixes=sorted(prefixes)
                 pl=profile.generate_prefix_list(name,prefixes,strict)
-                result+=[(pp,name,pl)]
-        return result
+                yield (pp,name,pl,prefixes,strict)
     @classmethod
     def global_pull(cls):
+        from noc.peer.models import PrefixListCache
         objects={}
         for o in PrefixList.objects.all():
             objects[o.repo_path]=o
+        c_objects=set() # peering_point/name
         logging.debug("PrefixList.global_pull(): building prefix lists")
-        for peering_point,pl_name,pl in PrefixList.build_prefix_lists():
+        for peering_point,pl_name,pl,prefixes,strict in PrefixList.build_prefix_lists():
             logging.debug("PrefixList.global_pull(): writing %s/%s (%d lines)"%(peering_point.hostname,pl_name,len(pl.split("\n"))))
             path=os.path.join(peering_point.hostname,pl_name)
             if path in objects:
@@ -381,8 +373,26 @@ class PrefixList(Object):
                 o=PrefixList(repo_path=path)
                 o.save()
             o.write(pl)
+            # Populate cache
+            try:
+                c=PrefixListCache.objects.get(peering_point=peering_point,name=pl_name)
+                if c.data!=prefixes:
+                    logging.debug("Updating cache for %s/%s"%(peering_point.hostname,pl_name))
+                    c.changed=datetime.datetime.now()
+                    c.data=prefixes
+                    c.save()
+            except PrefixListCache.DoesNotExist:
+                logging.debug("Updating cache for %s/%s"%(peering_point.hostname,pl_name))
+                PrefixListCache(peering_point=peering_point,name=pl_name,data=prefixes,strict=strict).save()
+            c_objects.add("%s/%s"%(peering_point.hostname,pl_name))
+        # Remove deleted prefix lists
         for o in objects.values():
             o.delete()
+        # Remove unused cache entries
+        for o in PrefixListCache.objects.all():
+            n="%s/%s"%(o.peering_point.hostname,o.name)
+            if n not in c_objects:
+                o.delete()
 ##
 ## DNS
 ##
