@@ -15,7 +15,7 @@ class DNSServerAdmin(admin.ModelAdmin):
     list_filter=["generator_name"]
     
 class DNSZoneProfileAdmin(admin.ModelAdmin):
-    pass
+    filter_horizontal=["masters","slaves"]
 
 class DNSZoneRecordInlineForm(forms.ModelForm):
     class Meta:
@@ -39,7 +39,7 @@ class DNSZoneRecordInline(admin.TabularInline):
     
 class DNSZoneAdmin(admin.ModelAdmin):
     inlines=[DNSZoneRecordInline]
-    list_display=["name","description","is_auto_generated","paid_till","serial","distribution","rpsl_link"]
+    list_display=["name","description","paid_till","is_auto_generated","profile","serial","distribution","rpsl_link"]
     list_filter=["is_auto_generated","profile"]
     search_fields=["name","description"]
     
