@@ -11,7 +11,8 @@ from django.conf.urls.defaults import *
 from django.contrib.auth.decorators import login_required
 from noc.fm.views import index,event,reclassify_event,open_event,close_event,create_rule,event_list_css,view_rules,\
     py_event_class,py_event_classification_rule,upload_mib,lookup_managed_object,lookup_events,reload_classifier_config,\
-    clone_rule,create_postprocessing_rule,py_event_correlation_rule,reload_correlator_config,active_problems_summary
+    clone_rule,create_postprocessing_rule,clone_postprocessing_rule,py_event_correlation_rule,reload_correlator_config,\
+    active_problems_summary
 
 urlpatterns = patterns ( "",
     (r"^(?P<event_id>\d+)/status/reclassify/$", login_required(reclassify_event)),
@@ -32,5 +33,6 @@ urlpatterns = patterns ( "",
     (r"^reload_classifier_config", login_required(reload_classifier_config)),
     (r"^reload_correlator_config", login_required(reload_correlator_config)),
     (r"^clone_rule/(?P<rule_id>\d+)/$", login_required(clone_rule)),
+    (r"^clone_postprocessing_rule/(?P<rule_id>\d+)/$", login_required(clone_postprocessing_rule)),
     (r"^active_problems_summary/$", login_required(active_problems_summary)),
 )
