@@ -36,6 +36,8 @@ class INETField(models.Field):
         return str(value)
     
     def get_db_prep_value(self,value):
+        if not value:
+            return None
         return value
 ##
 ## Binary Field maps to PostgreSQL BYTEA
@@ -59,6 +61,25 @@ class TextArrayField(models.Field):
             else:
                 return unicode(s,"utf-8")
         return [to_unicode(x) for x in value]
+##
+## INETArrayField maps to PostgreSQL INET[] type
+##
+class InetArrayField(models.Field):
+    __metaclass__ = models.SubfieldBase
+    def db_type(self):
+        return "INET[]"
+
+    def to_python(self,value):
+        if type(value)==types.ListType:
+            return value
+        if value=="{}":
+            return []
+        return value[1:-1].split(",")
+        
+    def get_db_prep_value(self,value):
+        return "{ "+", ".join(value)+" }"
+        
+
 ##
 ## Pickled object
 ##
