@@ -19,6 +19,8 @@ urlpatterns = patterns ( None,
         (r"^databrowse/(.*)", superuser_required(databrowse.site.root)),
         (r"^report/(?P<report>[a-z0-9\-_.]+)/$", login_required(report)),
         (r"^report/$", login_required(report_index)),
+        (r"^calculator/(?P<calculator>[a-z0-9\-_.]+)/$", login_required(calculator)),
+        (r"^calculator/$", login_required(calculator_index)),
         (r"^success/$", login_required(success)),
         (r"^failure/$", login_required(failure)),
         (r"^menu/$",    login_required(menu)),
@@ -31,5 +33,5 @@ urlpatterns = patterns ( None,
         (r"^refbook/(?P<refbook_id>\d+)/(?P<record_id>\d+)/$",         login_required(refbook_item)),
         (r"^refbook/(?P<refbook_id>\d+)/(?P<record_id>\d+)/edit/$",    login_required(refbook_edit)),
         (r"^refbook/(?P<refbook_id>\d+)/(?P<record_id>\d+)/delete/$",  login_required(refbook_delete)),
-        (r"^time_pattern/(?P<time_pattern_id>\d+)/test/$",             login_required(time_pattern_test)),
+        (r"^time_pattern/test/(?P<time_patterns>\d+(?:,\d+)*)/$",      login_required(test_time_patterns)),
 )
