@@ -19,6 +19,7 @@ from django import forms
 from django.views.generic import list_detail
 from noc.lib.render import render,render_success,render_failure,render_json
 from noc.main.report import report_registry
+from noc.main.calculator import calculator_registry
 from noc.main.menu import MENU
 from noc.main.search import search as search_engine
 from noc.main.models import RefBook, RefBookData, TimePattern
@@ -106,6 +107,20 @@ def report_index(request):
         out.append([k,v])
     return render(request,"main/report_index.html",{"reports":out})
 ##
+##
+##
+def calculator(request,calculator):
+    try:
+        c=calculator_registry[calculator]()
+    except KeyError:
+        return HttpResponseNotFound("No calculator found")
+    return c.render(request)
+
+def calculator_index(request):
+    r=[(cn,c.title) for cn,c in calculator_registry.classes.items()]
+    r=sorted(r,lambda x,y: cmp(x[1],y[1]))
+    return render(request,"main/calculator_index.html",{"calculators":r})
+##
 ## Success page
 ##
 def success(request):
@@ -330,23 +345,24 @@ def refbook_delete(request,refbook_id,record_id):
     rbd.delete()
     return HttpResponseRedirect("/main/refbook/%d/"%rb.id)
 ##
-## Test Time Pattern
+## Test Time Patterns
 ##
-class TimePatternTestForm(forms.Form):
+class TestTimePatternsForm(forms.Form):
     time=forms.DateTimeField(input_formats=["%d.%m.%Y %H:%M:%S"])
     
-def time_pattern_test(request,time_pattern_id):
-    time_pattern=get_object_or_404(TimePattern,id=int(time_pattern_id))
-    result=None
+def test_time_patterns(request,time_patterns):
+    tp=[get_object_or_404(TimePattern,id=int(x)) for x in time_patterns.split(",")]
+    result=[]
     if request.POST:
-        form=TimePatternTestForm(request.POST)
+        form=TestTimePatternsForm(request.POST)
         if form.is_valid():
-            result=time_pattern.match(form.cleaned_data["time"])
+            t=form.cleaned_data["time"]
+            result=[{"pattern":p,"result":p.match(t)} for p in tp]
     else:
         now=datetime.datetime.now()
         s="%02d.%02d.%04d %02d:%02d:%02d"%(now.day,now.month,now.year,now.hour,now.minute,now.second)
-        form=TimePatternTestForm(initial={"time":s})
-    return render(request,"main/time_pattern_test.html",{"time_pattern":time_pattern,"form":form,"result":result})
+        form=TestTimePatternsForm(initial={"time":s})
+    return render(request,"main/test_time_patterns.html",{"form":form,"result":result})
 ##
 ## CSV Export
 ##
