@@ -10,8 +10,9 @@ from noc.settings import config
 from noc.lib.validators import check_asn,check_as_set,is_ipv4,is_cidr
 from noc.lib.tt import tt_url,admin_tt_url
 from noc.lib.rpsl import rpsl_format
-from noc.lib.fields import INETField
+from noc.lib.fields import INETField,InetArrayField
 from noc.sa.profiles import profile_registry
+from noc.main.models import NotificationGroup
 from noc.cm.models import PrefixList
 from noc.sa.models import AdministrativeDomain
 from noc.main.menu import Menu
@@ -91,10 +92,6 @@ class Person(models.Model):
             s+=[self.extra]
         return rpsl_format("\n".join(s))
     rpsl=property(_rpsl)
-    def rpsl_link(self):
-        return "<A HREF='/peer/person/%d/rpsl/'>RPSL</A>"%self.id
-    rpsl_link.short_description="RPSL"
-    rpsl_link.allow_tags=True
 
 class Maintainer(models.Model):
     class Meta:
@@ -120,10 +117,6 @@ class Maintainer(models.Model):
             s+=[self.extra]
         return rpsl_format("\n".join(s))
     rpsl=property(_rpsl)
-    def rpsl_link(self):
-        return "<A HREF='/peer/maintainer/%d/rpsl/'>RPSL</A>"%self.id
-    rpsl_link.short_description="RPSL"
-    rpsl_link.allow_tags=True
 
 class Organisation(models.Model):
     class Meta:
@@ -172,7 +165,7 @@ class AS(models.Model):
         if self.header_remarks:
             s+=["remarks: %s"%x for x in self.header_remarks.split("\n")]
         # Find AS peers
-        pg={} # Peer Group -> AS -> peering_point -> [(import, export, localpref, remark)]
+        pg={} # Peer Group -> AS -> peering_point -> [(import, export, localpref, import_med, export_med, remark)]
         for peer in self.peer_set.filter(status="A"):
             if peer.peer_group not in pg:
                 pg[peer.peer_group]={}
@@ -181,12 +174,14 @@ class AS(models.Model):
             if peer.peering_point not in pg[peer.peer_group][peer.remote_asn]:
                 pg[peer.peer_group][peer.remote_asn][peer.peering_point]=[]
             to_skip=False
-            for p_import,p_export,localpref,remark in pg[peer.peer_group][peer.remote_asn][peer.peering_point]:
-                if peer.import_filter==p_import and peer.export_filter==p_export:
+            e_import_med=peer.effective_import_med
+            e_export_med=peer.effective_export_med
+            for p_import,p_export,localpref,import_med,export_med,remark in pg[peer.peer_group][peer.remote_asn][peer.peering_point]:
+                if peer.import_filter==p_import and peer.export_filter==p_export and e_import_med==import_med and e_export_med==export_med:
                     to_skip=True
                     break
             if not to_skip:
-                pg[peer.peer_group][peer.remote_asn][peer.peering_point]+=[(peer.import_filter,peer.export_filter,peer.local_pref,peer.rpsl_remark)]
+                pg[peer.peer_group][peer.remote_asn][peer.peering_point]+=[(peer.import_filter,peer.export_filter,peer.effective_local_pref,e_import_med,e_export_med,peer.rpsl_remark)]
         # Build RPSL
         inverse_pref=config.getboolean("peer","rpsl_inverse_pref_style")
         for peer_group in pg:
@@ -196,7 +191,7 @@ class AS(models.Model):
             for asn in sorted(pg[peer_group]):
                 add_at=len(pg[peer_group][asn])!=1
                 for pp in pg[peer_group][asn]:
-                    for import_filter,export_filter,localpref,remark in pg[peer_group][asn][pp]:
+                    for import_filter,export_filter,localpref,import_med,export_med,remark in pg[peer_group][asn][pp]:
                         # Prepend import and export with remark when given
                         if remark:
                             s+=["remarks: # %s"%remark]
@@ -204,15 +199,22 @@ class AS(models.Model):
                         i_s="import: from AS%d"%asn
                         if add_at:
                             i_s+=" at %s"%pp.hostname
+                        actions=[]
                         if localpref:
                             pref=(65535-localpref) if inverse_pref else localpref
-                            i_s+=" action pref=%d;"%pref
+                            actions+=["pref=%d;"%pref]
+                        if import_med:
+                            actions+=["med=%d;"%import_med]
+                        if actions:
+                            i_s+=" action "+" ".join(actions)
                         i_s+=" accept %s"%import_filter
                         s+=[i_s]
                         # Build export statement
                         e_s="export: to AS%d"%asn
                         if add_at:
                             e_s+=" at %s"%pp.hostname
+                        if export_med:
+                            e_s+=" action med=%d;"%export_med
                         e_s+=" announce %s"%export_filter
                         s+=[e_s]
         # Add contacts
@@ -231,21 +233,6 @@ class AS(models.Model):
         return rpsl_format("\n".join(s))
     rpsl=property(_rpsl)
     
-    def rpsl_link(self):
-        return "<A HREF='/peer/AS/%d/rpsl/'>RPSL</A>"%self.asn
-    rpsl_link.short_description="RPSL"
-    rpsl_link.allow_tags=True
-    ##
-    ## Lint to update RIR's DB
-    ##
-    def update_rir_db_link(self):
-        u=get_user()
-        if not u or not u.is_superuser:
-            return ""
-        return "<A HREF='/peer/AS/%d/rpsl/update/'>Update %s DB</A>"%(self.asn,self.rir.name)
-    update_rir_db_link.short_description="Update RIR DB"
-    update_rir_db_link.allow_tags=True
-    
     def _dot(self):
         s=["graph {"]
         all_peers=Peer.objects.filter(local_asn__exact=self)
@@ -328,10 +315,6 @@ class ASSet(models.Model):
             s+=self.rpsl_footer.split("\n")
         return rpsl_format("\n".join(s))
     rpsl=property(_rpsl)
-    def rpsl_link(self):
-        return "<A HREF='/peer/AS-SET/%s/rpsl/'>RPSL</A>"%self.name
-    rpsl_link.short_description="RPSL"
-    rpsl_link.allow_tags=True
 
 class PeeringPoint(models.Model):
     class Meta:
@@ -343,6 +326,8 @@ class PeeringPoint(models.Model):
     router_id=models.IPAddressField("Router-ID",unique=True)
     profile_name=models.CharField("Profile",max_length=128,choices=profile_registry.choices)
     communities=models.CharField("Import Communities",max_length=128,blank=True,null=True)
+    enable_prefix_list_provisioning=models.BooleanField("Enable Prefix-List Provisioning",default=False)
+    prefix_list_notification_group=models.ForeignKey(NotificationGroup,verbose_name="Prefix List Notification Group",null=True,blank=True)
     def __str__(self):
         if self.location:
             return "%s (%s)"%(self.hostname,self.location)
@@ -391,6 +376,9 @@ class PeeringPoint(models.Model):
         for p in self.peer_set.all():
             ifaddrs.add(p.local_ip)
             peers[p.remote_ip,p.remote_asn]=None
+            if p.local_backup_ip and p.remote_backup_ip:
+                ifaddrs.add(p.local_backup_ip)
+                peers[p.remote_backup_ip,p.remote_asn]=None
         s=[]
         s+=["inet-rtr: %s"%self.hostname]
         s+=["local-as: AS%d"%self.local_as.asn]
@@ -406,10 +394,6 @@ class PeeringPoint(models.Model):
             s+=["peer: BGP4 %s asno(%s)"%(remote_ip,remote_as)]
         return rpsl_format("\n".join(s))
     rpsl=property(_rpsl)
-    def rpsl_link(self):
-        return "<A HREF='/peer/INET-RTR/%s/rpsl/'>RPSL</A>"%self.hostname
-    rpsl_link.short_description="RPSL"
-    rpsl_link.allow_tags=True
 
 class PeerGroup(models.Model):
     class Meta:
@@ -419,6 +403,9 @@ class PeerGroup(models.Model):
     description=models.CharField("Description",max_length=64)
     communities=models.CharField("Import Communities",max_length=128,blank=True,null=True)
     max_prefixes=models.IntegerField("Max. Prefixes",default=100)
+    local_pref=models.IntegerField("Local Pref",null=True,blank=True)
+    import_med=models.IntegerField("Import MED",blank=True,null=True)
+    export_med=models.IntegerField("Export MED",blank=True,null=True)
     def __str__(self):
         return self.name
     def __unicode__(self):
@@ -434,11 +421,15 @@ class Peer(models.Model):
     peering_point=models.ForeignKey(PeeringPoint,verbose_name="Peering Point")
     local_asn=models.ForeignKey(AS,verbose_name="Local AS")
     local_ip=INETField("Local IP")
+    local_backup_ip=INETField("Local Backup IP",null=True,blank=True)
     remote_asn=models.IntegerField("Remote AS")
     remote_ip=INETField("Remote IP")
+    remote_backup_ip=INETField("Remote Backup IP",null=True,blank=True)
     status=models.CharField("Status",max_length=1,default="A",choices=[("P","Planned"),("A","Active"),("S","Shutdown")])
     import_filter=models.CharField("Import filter",max_length=64)
-    local_pref=models.IntegerField("Local Pref",null=True,blank=True)
+    local_pref=models.IntegerField("Local Pref",null=True,blank=True) # Override PeerGroup.local_pref
+    import_med=models.IntegerField("Import MED",blank=True,null=True) # Override PeerGroup.import_med
+    export_med=models.IntegerField("Export MED",blank=True,null=True) # Override PeerGroup.export_med
     export_filter=models.CharField("Export filter",max_length=64)
     description=models.CharField("Description",max_length=64,null=True,blank=True)
     rpsl_remark=models.CharField("RPSL Remark",max_length=64,null=True,blank=True)           # Peer remark to be shown in RPSL
@@ -484,6 +475,20 @@ class Peer(models.Model):
         return "<BR/>".join(r)
     admin_export_filter.short_description="Export Filter"
     admin_export_filter.allow_tags=True
+    def admin_local_ip(self):
+        r=[self.local_ip]
+        if self.local_backup_ip:
+            r+=[self.local_backup_ip]
+        return "<BR/>".join(r)
+    admin_local_ip.short_description="Local Address"
+    admin_local_ip.allow_tags=True
+    def admin_remote_ip(self):
+        r=[self.remote_ip]
+        if self.remote_backup_ip:
+            r+=[self.remote_backup_ip]
+        return "<BR/>".join(r)
+    admin_remote_ip.short_description="Local Address"
+    admin_remote_ip.allow_tags=True
     def _all_communities(self):
         r={}
         for cl in [self.peering_point.communities,self.peer_group.communities,self.communities]:
@@ -499,15 +504,29 @@ class Peer(models.Model):
     def _rpsl(self):
         s="import: from AS%d"%self.remote_asn
         s+=" at %s"%self.peering_point.hostname
-        if self.local_pref:
+        actions=[]
+        local_pref=self.effective_local_pref
+        if local_pref:
             # Select pref meaning
             if config.getboolean("peer","rpsl_inverse_pref_style"):
-                pref=65535-self.local_pref # RPSL style
+                pref=65535-local_pref # RPSL style
             else:
-                pref=self.local_pref                
-            s+=" action pref=%d;"%pref
+                pref=local_pref
+            actions+=["pref=%d;"%pref]
+        import_med=self.effective_import_med
+        if import_med:
+            actions+=["med=%d;"%import_med]
+        if actions:
+            s+=" action "+" ".join(actions)
         s+=" accept %s\n"%self.import_filter
-        s+="export: to AS%s at %s announce %s"%(self.remote_asn,self.peering_point.hostname,self.export_filter)
+        actions=[]
+        export_med=self.effective_export_med
+        if export_med:
+            actions+=["med=%d;"%export_med]
+        s+="export: to AS%s at %s"%(self.remote_asn,self.peering_point.hostname)
+        if actions:
+            s+=" action "+" ".join(actions)
+        " announce %s"%self.export_filter
         return s
     rpsl=property(_rpsl)
     def _effective_max_prefixes(self):
@@ -517,6 +536,30 @@ class Peer(models.Model):
             return self.peer_group.max_prefixes
         return 0
     effective_max_prefixes=property(_effective_max_prefixes)
+    ##
+    ## Effective localpref: Peer specific or PeerGroup inherited
+    ##
+    def _effective_local_pref(self):
+        if self.local_pref is not None:
+            return self.local_pref
+        return self.peer_group.local_pref
+    effective_local_pref=property(_effective_local_pref)
+    ##
+    ## Effective import med: Peer specific or PeerGroup inherited
+    ##
+    def _effective_import_med(self):
+        if self.import_med is not None:
+            return self.import_med
+        return self.peer_group.import_med
+    effective_import_med=property(_effective_import_med)
+    ##
+    ## Effective export med: Peer specific or PeerGroup inherited
+    ##
+    def _effective_export_med(self):
+        if self.export_med is not None:
+            return self.export_med
+        return self.peer_group.export_med
+    effective_export_med=property(_effective_export_med)
 ##
 ## Whois Database
 ##
@@ -665,6 +708,21 @@ class WhoisCache(models.Model):
                         wc=WhoisCache(lookup=wl,key=key,value="|".join(value))
                         wc.save()
         return True
+##
+##
+##
+class PrefixListCache(models.Model):
+    class Meta:
+        verbose_name="Prefix List Cache"
+        verbose_name_plural="Prefix List Cache"
+    peering_point=models.ForeignKey(PeeringPoint,verbose_name="Peering Point")
+    name=models.CharField("Name",max_length=64)
+    data=InetArrayField("Data")
+    strict=models.BooleanField("Strict")
+    changed=models.DateTimeField("Changed",auto_now=True,auto_now_add=True)
+    pushed=models.DateTimeField("Pushed",blank=True,null=True)
+    def __unicode__(self):
+        return u"%s/%s"%(self.peering_point.hostname,self.name)
 
 ##
 ## Application Menu
