@@ -14,42 +14,10 @@ from noc.lib.validators import is_asn,is_as_set,is_ipv4,is_cidr,is_fqdn
 from noc.peer.resolver import resolve_as_set_prefixes
 import re
 
-def as_rpsl(request,asn):
-    assert is_asn(asn)
-    asn=get_object_or_404(AS,asn=int(asn))
-    return render_plain_text(asn.rpsl)
-##
-## Interactively update RIR's DB
-##
-def as_rpsl_update(request,asn):
-    if not request.user.is_superuser:
-        return HttpResponseForbidden("Super-User privileges required")
-    assert is_asn(asn)
-    asn=get_object_or_404(AS,asn=int(asn))
-    return render_plain_text(asn.update_rir_db())
-    
 def as_dot(request,asn):
     assert is_asn(asn)
     asn=get_object_or_404(AS,asn=int(asn))
     return render(request,"peer/as_dot.html",{"asn":asn})
-
-def as_set_rpsl(request,as_set):
-    assert is_as_set(as_set)
-    as_set=get_object_or_404(ASSet,name=as_set)
-    return render_plain_text(as_set.rpsl)
-    
-def inet_rtr_rpsl(request,router):
-    assert is_fqdn(router)
-    peering_point=get_object_or_404(PeeringPoint,hostname=router)
-    return render_plain_text(peering_point.rpsl)
-
-def person_rpsl(request,person_id):
-    person=get_object_or_404(Person,id=int(person_id))
-    return render_plain_text(person.rpsl)
-
-def maintainer_rpsl(request,mnt_id):
-    maintainer=get_object_or_404(Maintainer,id=int(mnt_id))
-    return render_plain_text(maintainer.rpsl)
 ##
 ## Prefix List Builder
 ##
@@ -71,7 +39,7 @@ def prefix_list_builder(request):
         if form.is_valid():
             prefixes=resolve_as_set_prefixes(form.cleaned_data["as_set"],True)
             prefixes=sorted(prefixes)
-            pl=form.cleaned_data["peering_point"].profile.generate_prefix_list(form.cleaned_data["name"],prefixes,True)
+            pl=form.cleaned_data["peering_point"].profile.generate_prefix_list(form.cleaned_data["name"],prefixes,False)
     else:
         form=PrefixListBuilderForm()
     return render(request,"peer/prefix_list.html",{"form":form,"prefix_list":pl})
