@@ -13,6 +13,8 @@ from noc.pm.views import *
 
 urlpatterns = patterns ( "",
     (r"^$",                   login_required(index)),
-    (r"^view/(?P<chart_id>\d+)/$", login_required(view)),
-    (r"^data/(?P<chart_id>\d+)/$", login_required(data)),
+    (r"^view/chart/(?P<chart_id>\d+)/$", login_required(view_chart)),
+    (r"^data/chart/(?P<chart_id>\d+)/$", login_required(chart_data)),
+    (r"^view/ts/(?P<ts_id>\d+)/$",       login_required(view_ts)),
+    (r"^data/ts/(?P<ts_id>\d+)/$",       login_required(ts_data)),
 )
