@@ -8,16 +8,35 @@
 from django.contrib import admin
 from django import forms
 from models import *
+from noc.lib.render import render
+from noc.lib.admin_actions import enable_selected,disable_selected
 from noc.lib.fileutils import in_dir
 from noc.settings import config
-import os
+import os,datetime
 
 class ActivatorAdmin(admin.ModelAdmin):
     list_display=["name","ip","is_active"]
     
 class TaskScheduleAdmin(admin.ModelAdmin):
-    list_display=["periodic_name","is_enabled","run_every","next_run","run_now_link"]
+    list_display=["periodic_name","is_enabled","run_every","next_run"]
     search_fields=["periodic_name"]
+    actions=["run_now",enable_selected,disable_selected]
+    ##
+    ## Reschedule selected tasks
+    ##
+    def run_now(self,request,queryset):
+        updated=0
+        now=datetime.datetime.now()
+        for t in queryset:
+            t.next_run=now
+            t.save()
+            updated+=1
+        if updated==1:
+            message="1 task rescheduled"
+        else:
+            message="%d tasks rescheduled"%updated
+        self.message_user(request,message)
+    run_now.short_description="Run selected tasks now"
 
 class AdministrativeDomainAdmin(admin.ModelAdmin):
     list_display=["name","description"]
@@ -40,6 +59,8 @@ class ManagedObjectAdminForm(forms.ModelForm):
     # Check repo_path remains inside repo
     def clean_repo_path(self):
         repo=os.path.join(config.get("cm","repo"),"config")
+        if self.cleaned_data["repo_path"] and self.cleaned_data["repo_path"].startswith("."):
+            raise forms.ValidationError("Invalid repo path")
         if not in_dir(os.path.join(repo,self.cleaned_data["repo_path"]),repo) or self.cleaned_data["repo_path"].startswith(os.sep):
             raise forms.ValidationError("Repo path must be relative path inside repo")
         return os.path.normpath(self.cleaned_data["repo_path"])
@@ -109,8 +130,16 @@ class UserAccessAdmin(admin.ModelAdmin):
 ##
 ##
 class ManagedObjectSelectorAdmin(admin.ModelAdmin):
-    list_display=["name","is_enabled","test_link"]
+    list_display=["name","is_enabled"]
     list_filter=["is_enabled"]
+    actions=["test_selectors"]
+    ##
+    ## Test selected seletors
+    ##
+    def test_selectors(self,request,queryset):
+        r=[{"name":q.name,"objects":q.managed_objects} for q in queryset]
+        return render(request,"sa/test_selector.html",{"data":r})
+    test_selectors.short_description="Test Selectors"
 
 admin.site.register(Activator,            ActivatorAdmin)
 admin.site.register(AdministrativeDomain, AdministrativeDomainAdmin)
