@@ -16,7 +16,7 @@ from noc.sa.script import script_registry
 from noc.sa.protocols.sae_pb2 import TELNET,SSH,HTTP
 from noc.main.menu import Menu
 from noc.main.search import SearchResult
-from noc.lib.fields import PickledField
+from noc.lib.fields import PickledField,INETField
 
 profile_registry.register_all()
 periodic_registry.register_all()
@@ -86,7 +86,7 @@ class ManagedObject(models.Model):
     password=models.CharField("Password",max_length=32,blank=True,null=True)
     super_password=models.CharField("Super Password",max_length=32,blank=True,null=True)
     remote_path=models.CharField("Path",max_length=32,blank=True,null=True)
-    trap_source_ip=models.IPAddressField("Trap Source IP",null=True)
+    trap_source_ip=INETField("Trap Source IP",null=True,blank=True,default=None)
     trap_community=models.CharField("Trap Community",blank=True,null=True,max_length=64)
     snmp_ro=models.CharField("RO Community",blank=True,null=True,max_length=64)
     snmp_rw=models.CharField("RW Community",blank=True,null=True,max_length=64)
@@ -276,17 +276,6 @@ class TaskSchedule(models.Model):
             TaskSchedule.objects.filter(next_run__lte=datetime.datetime.now(),is_enabled=True).exclude(id__in=exclude).order_by("-next_run")
         else:
             return TaskSchedule.objects.filter(next_run__lte=datetime.datetime.now(),is_enabled=True).order_by("-next_run")
-
-    ##
-    ## Link to relaunch task
-    ##
-    def run_now_link(self):
-        try:
-            return "<A HREF='/sa/task/%d/now/'>Run Now</A>"%(self.id)
-        except:
-            return ""
-    run_now_link.short_description="Run Now"
-    run_now_link.allow_tags=True
 ##
 ## Object Selector
 ##
@@ -358,16 +347,6 @@ class ManagedObjectSelector(models.Model):
         return r.exclude(profile_name="NOC")
     managed_objects=property(_managed_objects)
     ##
-    ## Link to the test
-    ##
-    def test_link(self):
-        try:
-            return "<A HREF='/sa/test_selector/%d/'>Test Selector</A>"%(self.id)
-        except:
-            return ""
-    test_link.short_description="Test Selector"
-    test_link.allow_tags=True
-    ##
     ## Check Managed Object matches selector
     ##
     def match(self,managed_object):
@@ -442,6 +421,20 @@ class ReduceTask(models.Model):
     ##
     def get_result(self):
         return reduce_script_registry[self.reduce_script].execute(self)
+    ##
+    ## Wait untill all task complete
+    ##
+    @classmethod
+    def wait_for_tasks(cls,tasks):
+        while tasks:
+            time.sleep(3)
+            rest=[]
+            for t in tasks:
+                if t.complete:
+                    t.get_result() # delete task and trigger reduce task
+                else:
+                    rest+=[t]
+                tasks=rest
 ##
 ## Map Tasks
 ##
