@@ -17,5 +17,18 @@ class Profile(noc.sa.profiles.Profile):
     pattern_more="^ --More--"
     pattern_unpriveleged_prompt=r"^\S+?>"
     command_super="enable"
+    command_enter_config="configure terminal"
+    command_leave_config="exit"
+    command_save_config="write memory"
     pattern_prompt=r"^\S+?#"
     command_submit="\r"
+    
+    def generate_prefix_list(self,name,pl,strict=True):
+        suffix=""
+        if not strict:
+            suffix+=" le 32"
+        p="no ip prefix-list %s\n"%name
+        p+="ip prefix-list %s\n"%name
+        p+="\n".join(["    permit %s%s"%(x,suffix) for x in pl])
+        p+="\nexit\n"
+        return p
