@@ -14,9 +14,11 @@ from noc.sa.protocols.sae_pb2 import TELNET,SSH
 class Profile(noc.sa.profiles.Profile):
     name="Juniper.JUNOS"
     supported_schemes=[TELNET,SSH]
-    pattern_prompt="^({master}\n)?\S*>"
+    pattern_prompt=r"^(({master}\n)?\S+>)|(({master})?\[edit.*?\]\n\S+#)|(\[Type \^D at a new line to end input\])"
     pattern_more=r"^---\(more.*?\)---"
     command_more=" "
+    command_enter_config="configure"
+    command_leave_config="commit and-quit"
     pattern_lg_as_path_list=r"(?<=AS path: )(\d+(?: \d+)*)"
     pattern_lg_best_path=r"^(\s+[+*].+?\s+Router ID: \S+)"
     
