@@ -5,6 +5,7 @@
 ##----------------------------------------------------------------------
 """
 """
+from __future__ import with_statement
 from noc.lib.fsm import StreamFSM
 from noc.lib.ecma48 import strip_control_sequences
 from noc.lib.registry import Registry
@@ -12,7 +13,7 @@ from noc.lib.nbsocket import PTYSocket,UDPSocket,SocketTimeoutError
 from noc.lib.debug import format_frames,get_traceback_frames
 from noc.sa.protocols.sae_pb2 import TELNET,SSH,HTTP
 from noc.sa.profiles import profile_registry
-import logging,re,threading,Queue,urllib,httplib,random,base64,hashlib,cPickle,sys,time
+import logging,re,threading,Queue,urllib,httplib,random,base64,hashlib,cPickle,sys,time,datetime
 
 try:
     from pysnmp.carrier.asynsock.dispatch import AsynsockDispatcher
@@ -104,7 +105,10 @@ class ConfigurationContextManager(object):
     def __enter__(self):
         self.script.enter_config()
     def __exit__(self,exc_type, exc_val, exc_tb):
-        self.script.leave_config()
+        if exc_type is None:
+            self.script.leave_config()
+        else:
+            raise exc_type, exc_val
 ##
 ##
 ##
@@ -153,6 +157,32 @@ class Script(threading.Thread):
         self.kwargs=kwargs
         self.scripts=ScriptProxy(self)
         self.need_to_save=False
+        self.log_cli_sessions_path=None # Path to log CLI session
+        if self.parent:
+            self.log_cli_sessions_path=self.parent.log_cli_sessions_path
+        elif self.activator.log_cli_sessions\
+            and self.activator.log_cli_sessions_ip_re.search(self.access_profile.address)\
+            and self.activator.log_cli_sessions_script_re.search(self.name):
+            self.log_cli_sessions_path=self.activator.log_cli_sessions_path
+            for k,v in [
+                ("ip",self.access_profile.address),
+                ("script",self.name),
+                ("ts",datetime.datetime.now().strftime("%Y-%m-%d-%H-%M-%S"))]:
+                self.log_cli_sessions_path=self.log_cli_sessions_path.replace("{{%s}}"%k,v)
+            self.cli_debug("IP: %s SCRIPT: %s"%(self.access_profile.address,self.name),"!")
+    ##
+    ##
+    ##
+    def cli_debug(self,msg,chars=None):
+        if not self.log_cli_sessions_path:
+            return
+        m=datetime.datetime.now().strftime("[%Y-%m-%d %H:%M:%S] ")
+        if chars:
+            m+=chars*50
+        m+="\n"
+        m+=msg+"\n"
+        with open(self.log_cli_sessions_path,"a") as f:
+            f.write(m)
     ##
     ## Checks script is stale and must be terminated
     ##
@@ -243,14 +273,16 @@ class Script(threading.Thread):
             self.debug("CLI Provider is ready")
         return self.cli_provider
         
-    def cli(self,cmd):
+    def cli(self,cmd,command_submit=None,bulk_lines=None):
         self.debug("cli(%s)"%cmd)
+        self.cli_debug(cmd,">")
         self.request_cli_provider()
-        self.cli_provider.submit(cmd)
+        self.cli_provider.submit(cmd,command_submit=self.profile.command_submit if command_submit is None else command_submit,bulk_lines=bulk_lines)
         data=self.cli_queue_get()
         if self.strip_echo and data.lstrip().startswith(cmd):
             data=self.strip_first_lines(data.lstrip())
         self.debug("cli() returns:\n---------\n%s\n---------"%repr(data))
+        self.cli_debug(data,"<")
         return data
     ##
     ## Clean up config from all unnecessary trash
@@ -304,6 +336,7 @@ class Script(threading.Thread):
     def leave_config(self):
         if self.profile.command_leave_config:
             self.cli(self.profile.command_leave_config)
+            self.cli("") # Guardian empty command to wait until configuration is finally written
     # Save current config
     def save_config(self,immediately=False):
         if immediately:
@@ -374,7 +407,9 @@ class CLI(StreamFSM):
         self.queue=Queue.Queue()
         self.is_ready=False
         self.collected_data=""
-        self.prompt_patters=[x for x in [self.profile.pattern_more,self.profile.pattern_more_start,self.profile.pattern_more_end] if x]
+        self.submitted_data=[]
+        self.submit_lines_limit=None
+        self.prompt_patterns=[x for x in [self.profile.pattern_more,self.profile.pattern_more_start,self.profile.pattern_more_end] if x]
         StreamFSM.__init__(self)
     
     def on_read(self,data):
@@ -383,10 +418,25 @@ class CLI(StreamFSM):
             for rc in self.profile.rogue_chars:
                 data=data.replace(rc,"")
         self.feed(data,cleanup=strip_control_sequences)
+        self.__flush_submitted_data()
+    ##
+    ## Feed pending submitted data
+    ##
+    def __flush_submitted_data(self):
+        if self.submitted_data:
+            self.debug("%d lines to submit"%len(self.submitted_data))
+            sd="\n".join(self.submitted_data[:self.submit_lines_limit])+"\n"
+            self.submitted_data=self.submitted_data[self.submit_lines_limit:]
+            self.write(sd)
     
-    def submit(self,msg):
-        self.debug("submit(%s)"%repr(msg))
-        self.write(msg+self.profile.command_submit)
+    def submit(self,msg,command_submit=None,bulk_lines=None):
+        self.debug("submit(%s,bulk_lines=%s)"%(repr(msg),bulk_lines))
+        self.submit_lines_limit=bulk_lines
+        if bulk_lines:
+            self.submitted_data=msg.splitlines()
+            self.__flush_submitted_data()
+        else:
+            self.write(msg+(self.profile.command_submit if command_submit is None else command_submit))
     
     def on_START_enter(self):
         p=[
@@ -454,7 +504,7 @@ class CLI(StreamFSM):
         self.set_patterns(p)
         
     def on_PROMPT_match(self,data,match):
-        if match.re.pattern in self.prompt_patters:
+        if match.re.pattern in self.prompt_patterns:
             self.collected_data+=data
         elif match.re.pattern==self.profile.pattern_prompt:
             self.queue.put(self.collected_data+data)
