@@ -2,13 +2,18 @@
 #
 # Service Activation Engine
 #
-import os,sys,getopt
+import os,sys,site
 
 if __name__ == '__main__':
+    # Adjust paths
     d=os.path.dirname(sys.argv[0])
+    contrib=os.path.join(d,"..","contrib","lib")
+    sys.path.insert(0,contrib)
     sys.path.insert(0,os.path.join(d,"..",".."))
     sys.path.insert(0,os.path.join(d,".."))
     sys.path.insert(0,d)
+    # Install eggs from contrib/lib
+    site.addsitedir(contrib)
     try:
         import settings
     except ImportError:
@@ -17,4 +22,4 @@ if __name__ == '__main__':
     os.environ['DJANGO_SETTINGS_MODULE']="noc.settings"
     from noc.sa.sae import SAE
     sae=SAE()
-    sae.process_command()
\ No newline at end of file
+    sae.process_command()
